@@ -1,7 +1,7 @@
 import pytest
 
 from flask import  Flask, current_app
-from flask_jwt_oidc import AuthError, JwtManager
+from flask_jwt_oidc_mds import AuthError, JwtManager
 
 from examples.flask_app.app import create_app, jwt as _jwt
 from examples.flask_app.config import TestConfig
